@@ -3,7 +3,6 @@
 # If you want to add a Browser to extend AWStats database detection capabilities,
 # you must add an entry in BrowsersSearchIDOrder and in BrowsersHashIDLib.
 #-------------------------------------------------------
-# $Revision: 1.68 $ - $Author: eldy $ - $Date: 2012/12/05 13:14:22 $
 
 # 2006-05-15 Sean Carlos http://www.antezeta.com/awstats.html 
 # 				akregator (rss)
@@ -33,7 +32,8 @@
 	'opera'     => 5,
 	'safari'    => 6,
 	'chrome'    => 7,
-	'konqueror' => 8
+	'konqueror' => 8,
+	'edge'      => 9
 );
 
 # BrowsersSearchIDOrder
@@ -272,6 +272,7 @@
 'svn', 'Subversion client', 
 'msie','MS Internet Explorer',
 'netscape','Netscape',
+'edge','Edge',
 
 'elinks','ELinks',
 'firebird','Firebird (Old Firefox)',
@@ -524,6 +525,7 @@
 'svn','subversion',
 'msie','msie',
 'netscape','netscape',
+'edge','edge',
 
 'firebird','phoenix',
 'go!zilla','gozilla',
@@ -749,6 +751,9 @@
 
 # Browsers examples by engines
 #
+# -- Edge --
+# Mozilla/5.0 (Windows NT 10.0; <64-bit tags>) AppleWebKit/<WebKit Rev> (KHTML, like Gecko) Chrome/<Chrome Rev> Safari/<WebKit Rev> Edge/<EdgeHTML Rev>.<Windows Build>
+#
 # -- Mosaic --
 # MSIE		4.0  	Mozilla/4.0 (compatible; MSIE 5.0; Windows 98; DigExt; KITV4 Wanadoo; KITV5 Wanadoo)
 #
